yakumo.neutron.v2.metering.label

Package yakumo :: Package neutron :: Package v2 :: Package metering :: Module label |
[hide private]
[frames] | no frames]

# Module label

source code

Resource class and its manager for metering labels for Networking v2 API

Classes | [hide private]
| Resource Resource class for metering labels for Networking v2 API
| Manager Manager class for metering labels for Networking v2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.metering``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('project', 'tenant_id', mapper.Reso
      urce('project')),]